using System;
using System.Collections.Generic;
using System.Linq;

namespace Checkout
{
    public class ItemNotFoundException : Exception
    {
    }

    public class CheckoutCounter
    {
        private static Dictionary<string, double> itemPrices = new Dictionary<string, double>();
        private static Dictionary<string, int> itemQuantities = new Dictionary<string, int>();
        

        public static void Scan(string itemName)
        {
            if (itemName.Length != 0)
            {
                if (itemPrices.ContainsKey(itemName))
                    AddItem(itemName);
                else
                    throw new ItemNotFoundException();
            }
        }

        public static double CalculateTotalPrice()
        {
            return itemQuantities.Sum(item => item.Value*itemPrices[item.Key] - GetItemDiscount(item.Key));
        }

        private static double GetItemDiscount(string itemName)
        {
            
            return Discounts.GetDiscount(itemName, itemQuantities[itemName], itemPrices[itemName]);
        }

        private static void AddItem(string itemName)
        {
            int quantity;
            if (itemQuantities.TryGetValue(itemName, out quantity))
                itemQuantities[itemName] = ++quantity;
            else
                itemQuantities.Add(itemName, quantity = 1);
        }

        public static void SetItemPrices(Dictionary<string, double> newItemPrices)
        {
            itemPrices = newItemPrices;
        }

        public static void Reset()
        {
            itemQuantities.Clear();
        }
    }
}